import React from 'react';
import { motion, AnimatePresence } from "framer-motion"

export function Popup({ opened, title, close, children }) {

  const popupMotionVariants = {
    hidden: { opacity: 0, scale: .9 },
    visible: { opacity: 1, scale: 1 },
  }

  //document.body.style.overflow='hidden';
  // Если надо закрывать по клику за попапом, то в первый див надо добавить onClick={close}
  return <>
    <AnimatePresence>
      {opened &&
        <div className="modal z-50 fixed w-full min-h-screen top-0 left-0 flex items-center justify-center">
          <div className="modal-overlay absolute top-0 left-0 w-full h-full bg-gray-100 opacity-75"></div>
          <div className="modal-wrapper relative w-full">
            <div className="max-w-full max-h-screen sm:max-w-lg mx-auto">
              <motion.div
                variants={popupMotionVariants}
                initial="hidden"
                animate="visible"
                exit="hidden"
                transition={{ duration: .1 }}
              >
                <div className="ma-0 bg-white shadow-lg border-gray-500 border-t-2 border-b-2 sm:border-2 sm:mx-4 sm:rounded-lg transition-opacity duration-300" onClick={e => e.stopPropagation()}>
                  <div className="px-3 h-12 border-b border-gray-400 font-semibold relative flex items-center">
                    <div className="w-full text-xl">{title}</div>
                    <div className="absolute top-0 right-0 w-12 h-12 pb-1 text-3xl leading-none cursor-pointer flex items-center justify-center" onClick={close}>&times;</div>
                  </div>
                  <div className="">
                    {children}
                  </div>
                </div>
              </motion.div>
            </div>
          </div>
        </div>
      }
    </AnimatePresence>

  </>
}

export default Popup;
